@@ -90,6 +90,5 @@ class CBlackBoxHeaderEvasionProblem(CBlackBoxProblem):
 		"""
 		byte_values = (t * 255).astype(np.int)
 		x_adv = deepcopy(x)
-		for i, index in enumerate(self.indexes_to_perturb):
-			x_adv[0, index] = byte_values[i]
+		x_adv[0, self.indexes_to_perturb] = CArray(byte_values)
 		return CArray(x_adv)
